@@ -274,7 +274,7 @@ typedef struct {
 static gchar *
 get_url_to_use (U1MusicStore *music_store)
 {
-	gchar *oauth_consumer_token, *oauth_consumer_secret, *oauth_token = NULL, *oauth_token_secret = NULL, *real_url;
+	gchar *oauth_consumer_token = NULL, *oauth_consumer_secret = NULL, *oauth_token = NULL, *oauth_token_secret = NULL, *real_url = NULL;
 
 	/* OAUth sign the URL */
 	if (g_str_has_prefix (music_store->priv->base_url, "http://localhost") || g_str_has_prefix (music_store->priv->base_url, "http://127.0.0.1")) {
